# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import gea.models
import django_extensions.db.fields


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Antecedente',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('inscripcion_numero', models.IntegerField(blank=True, null=True, default=None)),
                ('duplicado', models.BooleanField(default=False)),
                ('obs', gea.models.CharNullField(max_length=255, blank=True, null=True, default=None)),
                ('plano_ruta', gea.models.URLNullField(max_length=100, blank=True, null=True, default=None)),
            ],
        ),
        migrations.CreateModel(
            name='Catastro',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('seccion', gea.models.CharNullField(max_length=10, blank=True, null=True, default=None)),
                ('poligono', gea.models.CharNullField(max_length=10, blank=True, null=True, default=None)),
                ('manzana', gea.models.CharNullField(max_length=10, blank=True, null=True, default=None)),
                ('parcela', gea.models.CharNullField(max_length=10, blank=True, null=True, default=None)),
                ('subparcela', gea.models.CharNullField(max_length=10, blank=True, null=True, default=None)),
            ],
        ),
        migrations.CreateModel(
            name='CatastroLocal',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('seccion', gea.models.CharNullField(max_length=20, blank=True, null=True, default=None)),
                ('manzana', gea.models.CharNullField(max_length=20, blank=True, null=True, default=None)),
                ('parcela', gea.models.CharNullField(max_length=20, blank=True, null=True, default=None)),
                ('subparcela', gea.models.CharNullField(max_length=20, blank=True, null=True, default=None)),
                ('suburbana', models.BooleanField(default=False)),
                ('poligono', gea.models.CharNullField(max_length=20, blank=True, null=True, default=None)),
            ],
            options={
                'verbose_name': 'catastro local',
                'verbose_name_plural': 'catastros locales',
            },
        ),
        migrations.CreateModel(
            name='Circunscripcion',
            fields=[
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('nombre', gea.models.CharNullField(max_length=10)),
                ('orden', gea.models.CharNullField(max_length=7)),
            ],
            options={
                'verbose_name_plural': 'circunscripciones',
                'ordering': ['id'],
            },
        ),
        migrations.CreateModel(
            name='Comprobante',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('nombre', gea.models.CharNullField(max_length=50)),
            ],
        ),
        migrations.CreateModel(
            name='Dp',
            fields=[
                ('dp', models.IntegerField(primary_key=True, serialize=False)),
                ('nombre', gea.models.CharNullField(verbose_name='nombre depto', max_length=50)),
                ('habitantes', models.IntegerField(blank=True, null=True)),
                ('superficie', models.IntegerField(blank=True, null=True)),
                ('cabecera', gea.models.CharNullField(max_length=50, blank=True, null=True)),
                ('circunscripcion', models.ForeignKey(to='gea.Circunscripcion')),
            ],
            options={
                'verbose_name_plural': 'Departamentos',
                'ordering': ['dp'],
            },
        ),
        migrations.CreateModel(
            name='Ds',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('ds', models.IntegerField()),
                ('nombre', gea.models.CharNullField(verbose_name='nombre distrito', max_length=50)),
                ('dp', models.ForeignKey(db_column='dp', to='gea.Dp')),
            ],
            options={
                'verbose_name_plural': 'distritos',
                'ordering': ['dp', 'ds'],
            },
        ),
        migrations.CreateModel(
            name='Expediente',
            fields=[
                ('created', django_extensions.db.fields.CreationDateTimeField(verbose_name='created', auto_now_add=True)),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(verbose_name='modified', auto_now=True)),
                ('id', models.IntegerField(verbose_name='Expediente Nº', primary_key=True, serialize=False)),
                ('fecha_plano', models.DateField(blank=True, null=True, default=None)),
                ('fecha_medicion', models.DateField(blank=True, null=True, default=None)),
                ('inscripcion_numero', models.IntegerField(verbose_name='SCIT inscripción Nº', unique=True, blank=True, null=True, default=None)),
                ('inscripcion_fecha', models.DateField(verbose_name='Fecha inscripción', blank=True, null=True, default=None)),
                ('duplicado', models.BooleanField(default=False)),
                ('orden_numero', models.IntegerField(verbose_name='CoPA Expendiente Nº', blank=True, null=True, default=None)),
                ('orden_fecha', models.DateField(verbose_name='Fecha contrato', blank=True, null=True, default=None)),
                ('sin_inscripcion', models.BooleanField(default=False)),
                ('cancelado', models.BooleanField(default=False)),
                ('cancelado_por', gea.models.CharNullField(max_length=100, blank=True, null=True, default=None)),
                ('plano_ruta', gea.models.URLNullField(max_length=100, blank=True, null=True, default=None)),
            ],
            options={
                'ordering': ['-id'],
            },
        ),
        migrations.CreateModel(
            name='ExpedienteLugar',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('expediente', models.ForeignKey(to='gea.Expediente')),
            ],
            options={
                'verbose_name': 'lugar',
                'verbose_name_plural': 'lugares',
                'ordering': ['expediente', 'lugar'],
            },
        ),
        migrations.CreateModel(
            name='ExpedienteObjeto',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('expediente', models.ForeignKey(to='gea.Expediente')),
            ],
            options={
                'verbose_name': 'objeto',
                'verbose_name_plural': 'objetos',
                'ordering': ['expediente', 'objeto'],
            },
        ),
        migrations.CreateModel(
            name='ExpedientePartida',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('set_ruta', gea.models.URLNullField(max_length=100, blank=True, null=True, default=None)),
                ('expediente', models.ForeignKey(to='gea.Expediente')),
            ],
            options={
                'verbose_name': 'partida',
                'verbose_name_plural': 'partidas',
                'ordering': ['expediente', 'partida'],
            },
        ),
        migrations.CreateModel(
            name='ExpedientePersona',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('comitente', models.BooleanField(default=False)),
                ('propietario', models.BooleanField(default=True)),
                ('poseedor', models.BooleanField(default=False)),
                ('sucesor', models.BooleanField(default=False)),
                ('partes_indivisas_propias', models.IntegerField(blank=True, null=True, default=None)),
                ('partes_indivisas_total', models.IntegerField(blank=True, null=True, default=None)),
                ('sucesion', models.BooleanField(default=False)),
                ('nuda_propiedad', models.BooleanField(default=False)),
                ('usufructo', models.BooleanField(default=False)),
                ('expediente', models.ForeignKey(to='gea.Expediente')),
            ],
            options={
                'verbose_name': 'persona involucrada',
                'verbose_name_plural': 'personas involucradas',
                'ordering': ['persona__apellidos', 'persona__nombres'],
            },
        ),
        migrations.CreateModel(
            name='ExpedienteProfesional',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('expediente', models.ForeignKey(to='gea.Expediente')),
            ],
            options={
                'verbose_name': 'profesional firmante',
                'verbose_name_plural': 'profesionales firmantes',
                'ordering': ['profesional__apellidos', 'profesional__nombres'],
            },
        ),
        migrations.CreateModel(
            name='Lugar',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('nombre', gea.models.CharNullField(max_length=80)),
                ('obs', gea.models.CharNullField(max_length=255, blank=True, null=True, default=None)),
            ],
            options={
                'verbose_name_plural': 'lugares',
                'ordering': ['nombre'],
            },
        ),
        migrations.CreateModel(
            name='Objeto',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('nombre', gea.models.CharNullField(max_length=80)),
            ],
            options={
                'ordering': ['nombre'],
            },
        ),
        migrations.CreateModel(
            name='Pago',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('comprobante_nro', models.IntegerField(blank=True, null=True, default=None)),
                ('fecha', models.DateField(blank=True, null=True, default=None)),
                ('monto', models.DecimalField(max_digits=8, decimal_places=2)),
                ('porcentaje', models.DecimalField(max_digits=5, decimal_places=2)),
                ('obs', gea.models.CharNullField(max_length=255, blank=True, null=True, default=None)),
                ('comprobante', models.ForeignKey(to='gea.Comprobante')),
            ],
        ),
        migrations.CreateModel(
            name='Partida',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('pii', models.IntegerField()),
                ('subpii', models.IntegerField()),
                ('api', models.SmallIntegerField(blank=True, null=True, default=0)),
            ],
            options={
                'ordering': ['pii', 'subpii'],
            },
        ),
        migrations.CreateModel(
            name='PartidaDominio',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('tomo', models.IntegerField(blank=True, null=True, default=None)),
                ('par', models.BooleanField(default=False)),
                ('impar', models.BooleanField(default=False)),
                ('folio', models.IntegerField(blank=True, null=True, default=None)),
                ('numero', models.IntegerField(blank=True, null=True, default=None)),
                ('fecha', models.DateField(blank=True, null=True, default=None)),
                ('fecha_inscripcion_definitiva', models.DateField(blank=True, null=True, default=None)),
                ('partida', models.ForeignKey(to='gea.Partida')),
            ],
            options={
                'verbose_name_plural': 'partida_dominios',
            },
        ),
        migrations.CreateModel(
            name='Persona',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('nombres', gea.models.CharNullField(max_length=100, blank=True, null=True, default=None)),
                ('apellidos', gea.models.CharNullField(max_length=100)),
                ('nombres_alternativos', gea.models.CharNullField(max_length=100, blank=True, null=True, default=None)),
                ('apellidos_alternativos', gea.models.CharNullField(max_length=100, blank=True, null=True, default=None)),
                ('domicilio', gea.models.CharNullField(max_length=50, blank=True, null=True, default=None)),
                ('telefono', gea.models.CharNullField(max_length=20, blank=True, null=True, default=None)),
                ('celular', gea.models.CharNullField(max_length=20, blank=True, null=True, default=None)),
                ('email', gea.models.EmailNullField(max_length=50, unique=True, blank=True, null=True, default=None)),
                ('cuit_cuil', gea.models.CharNullField(verbose_name='CUIT/CUIL/CDI', max_length=14, unique=True, blank=True, null=True, default=None)),
                ('tipo_doc', models.SmallIntegerField(blank=True, null=True, default=None, choices=[(0, 'DNI'), (1, 'LC'), (2, 'LE'), (3, 'Otro')])),
                ('documento', models.IntegerField(unique=True, blank=True, null=True, default=None)),
                ('lugar', models.ForeignKey(blank=True, null=True, default=None, to='gea.Lugar')),
            ],
            options={
                'ordering': ['apellidos', 'nombres'],
            },
        ),
        migrations.CreateModel(
            name='Presupuesto',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('monto', models.DecimalField(max_digits=8, decimal_places=2)),
                ('fecha', models.DateField()),
                ('porcentaje_cancelado', models.DecimalField(verbose_name='% cancelado', max_digits=5, decimal_places=2)),
                ('obs', gea.models.CharNullField(max_length=255, blank=True, null=True, default=None)),
                ('expediente', models.ForeignKey(to='gea.Expediente')),
            ],
            options={
                'ordering': ['expediente'],
            },
        ),
        migrations.CreateModel(
            name='Profesional',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('nombres', gea.models.CharNullField(max_length=50)),
                ('apellidos', gea.models.CharNullField(max_length=50)),
                ('icopa', gea.models.CharNullField(max_length=8, blank=True, null=True, default=None)),
                ('domicilio', gea.models.CharNullField(max_length=50, blank=True, null=True, default=None)),
                ('telefono', gea.models.CharNullField(max_length=20, blank=True, null=True, default=None)),
                ('celular', gea.models.CharNullField(max_length=20, blank=True, null=True, default=None)),
                ('web', gea.models.URLNullField(max_length=50, blank=True, null=True, default=None)),
                ('email', gea.models.EmailNullField(max_length=50, unique=True, blank=True, null=True, default=None)),
                ('cuit_cuil', gea.models.CharNullField(verbose_name='DNI/CUIT/CUIL/CDI', max_length=14, unique=True, blank=True, null=True, default=None)),
                ('habilitado', models.BooleanField(default=True)),
                ('jubilado', models.BooleanField(default=False)),
                ('fallecido', models.BooleanField(default=False)),
                ('lugar', models.ForeignKey(blank=True, null=True, default=None, to='gea.Lugar')),
            ],
            options={
                'verbose_name_plural': 'profesionales',
                'ordering': ['apellidos', 'nombres'],
            },
        ),
        migrations.CreateModel(
            name='Sd',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('sd', models.IntegerField()),
                ('nombre', gea.models.CharNullField(verbose_name='nombre subdistrito', max_length=50, blank=True, null=True, default=None)),
                ('ds', models.ForeignKey(db_column='ds', to='gea.Ds')),
            ],
            options={
                'verbose_name_plural': 'subdistritos',
                'ordering': ['ds', 'sd'],
            },
        ),
        migrations.CreateModel(
            name='Titulo',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('nombre', gea.models.CharNullField(max_length=30)),
            ],
            options={
                'ordering': ['nombre'],
            },
        ),
        migrations.CreateModel(
            name='Zona',
            fields=[
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('descripcion', gea.models.CharNullField(max_length=50)),
            ],
            options={
                'ordering': ['id'],
            },
        ),
        migrations.AddField(
            model_name='profesional',
            name='titulo',
            field=models.ForeignKey(blank=True, null=True, default=None, to='gea.Titulo'),
        ),
        migrations.AddField(
            model_name='partida',
            name='sd',
            field=models.ForeignKey(blank=True, null=True, default=None, db_column='sd', to='gea.Sd'),
        ),
        migrations.AddField(
            model_name='pago',
            name='presupuesto',
            field=models.ForeignKey(to='gea.Presupuesto'),
        ),
        migrations.AddField(
            model_name='expedienteprofesional',
            name='profesional',
            field=models.ForeignKey(to='gea.Profesional'),
        ),
        migrations.AddField(
            model_name='expedientepersona',
            name='persona',
            field=models.ForeignKey(to='gea.Persona'),
        ),
        migrations.AddField(
            model_name='expedientepartida',
            name='partida',
            field=models.ForeignKey(to='gea.Partida'),
        ),
        migrations.AddField(
            model_name='expedienteobjeto',
            name='objeto',
            field=models.ForeignKey(to='gea.Objeto'),
        ),
        migrations.AddField(
            model_name='expedientelugar',
            name='lugar',
            field=models.ForeignKey(to='gea.Lugar'),
        ),
        migrations.AddField(
            model_name='catastrolocal',
            name='expediente_lugar',
            field=models.ForeignKey(to='gea.ExpedienteLugar'),
        ),
        migrations.AddField(
            model_name='catastro',
            name='expediente_partida',
            field=models.ForeignKey(to='gea.ExpedientePartida'),
        ),
        migrations.AddField(
            model_name='catastro',
            name='zona',
            field=models.ForeignKey(blank=True, null=True, default=None, db_column='zona', to='gea.Zona'),
        ),
        migrations.AddField(
            model_name='antecedente',
            name='expediente',
            field=models.ForeignKey(blank=True, null=True, default=None, to='gea.Expediente'),
        ),
        migrations.AddField(
            model_name='antecedente',
            name='expediente_modificado',
            field=models.ForeignKey(blank=True, null=True, default=None, related_name='expediente_modificado', to='gea.Expediente'),
        ),
        migrations.AlterUniqueTogether(
            name='partida',
            unique_together=set([('pii', 'subpii')]),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import filebrowser.fields


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0004_auto_20170203_1731'),
    ]

    operations = [
        migrations.AddField(
            model_name='antecedente',
            name='plano',
            field=filebrowser.fields.FileBrowseField(verbose_name='Enlace al plano', max_length=200, blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='expediente',
            name='plano',
            field=filebrowser.fields.FileBrowseField(verbose_name='Enlace al plano', max_length=200, blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='expedientepartida',
            name='informe_catastral',
            field=filebrowser.fields.FileBrowseField(max_length=200, blank=True, null=True),
        ),
    ]



from django.urls import path

from gea.views import (
    About,
    CatastroLocalList,
    ExpedienteDetail,
    ExpedienteList,
    Home,
    PersonaDetail,
    PersonaList,
    caratula,
    catastro,
    dvapi,
    plano,
    set,
    sie,
    solicitud,
    visacion,
)

urlpatterns = [
    # Inicio
    path("", Home.as_view(), name="home"),
    # About
    path("acerca/", About.as_view(), name="about"),
    # Catastros Locales
    path("catastros-locales/", CatastroLocalList.as_view(), name="catastros_locales"),
    # Expedientes
    path("expedientes/", ExpedienteList.as_view(), name="expedientes"),
    path("expedientes/<int:pk>/", ExpedienteDetail.as_view(), name="expediente"),
    # Personas
    path("personas/", PersonaList.as_view(), name="personas"),
    path("personas/<int:pk>/", PersonaDetail.as_view(), name="persona"),
    # Notas
    path("solicitud/", solicitud, name="solicitud"),
    path("visacion/", visacion, name="visacion"),
    # Búsquedas
    path("plano/", plano, name="buscar_plano"),
    path("set/", set, name="buscar_set"),
    path("catastro/", catastro, name="buscar_catastro"),
    # Herramientas
    path("caratula/", caratula, name="caratula"),
    path("dvapi/", dvapi, name="dvapi"),
    path("sie/", sie, name="sie"),
]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import gea.models


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0005_auto_20170203_1943'),
    ]

    operations = [
        migrations.AlterField(
            model_name='antecedente',
            name='obs',
            field=gea.models.CharNullField(verbose_name='Observaciones', max_length=255, blank=True, null=True, default=None),
        ),
        migrations.AlterField(
            model_name='lugar',
            name='obs',
            field=gea.models.CharNullField(verbose_name='Observaciones', max_length=255, blank=True, null=True, default=None),
        ),
        migrations.AlterField(
            model_name='pago',
            name='obs',
            field=gea.models.CharNullField(verbose_name='Observaciones', max_length=255, blank=True, null=True, default=None),
        ),
        migrations.AlterField(
            model_name='presupuesto',
            name='obs',
            field=gea.models.CharNullField(verbose_name='Observaciones', max_length=255, blank=True, null=True, default=None),
        ),
    ]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['gea', 'gea.migrations', 'gea.templatetags']

package_data = \
{'': ['*'],
 'gea': ['static/css/*',
         'static/fonts/*',
         'static/img/*',
         'static/js/*',
         'templates/*',
         'templates/doc/*',
         'templates/home/*',
         'templates/lists/*',
         'templates/registration/*',
         'templates/search/*',
         'templates/tools/*']}

install_requires = \
['django-extensions>=2.2.9,<3.0.0',
 'django-nested-admin>=3.3.0,<4.0.0',
 'django>=3.0.6,<4.0.0']

setup_kwargs = {
    'name': 'gea',
    'version': '0.2.29',
    'description': 'Gestión de Expedientes de Agrimensores para Django.',
    'long_description': '# gea\n\nGestión de Expedientes de Agrimensores.\n\n__gea__ es una aplicación web basada en [Django](https://www.djangoproject.com/) para gestionar expedientes de agrimensores. Hasta ahora sólo fue usada en la provincia de _Santa Fe, Argentina_.\n\n## Requisitos previos\n\n- GNU/Linux\n- Python >= 3.6\n- [Django](https://pypi.python.org/pypi/Django/) 3.0.6\n- [psycopg2](https://pypi.python.org/pypi/psycopg2/) (opcional si utiliza PostgreSQL)\n- [django-nested-admin](https://pypi.python.org/pypi/django-nested-admin/) (para formularios anidados)\n\n## Instalación\n\n```bash\n$ pip install gea\n```\n\nSe instalan también los ```requirements``` como Django y nested-admin. Si además quiere utilizar PostgreSQL para la Base de Datos, deberá instalar manualmente psycopg2.\n\n```bash\n$ pip install psycopg2\n```\n\n## Puesta en marcha\n\n### Crear proyecto Django\n\n```bash\n$ django-admin startproject estudio\n```\n\n### Editar ```settings.py``` del proyecto Django:\n\n```bash\n$ # dentro de "estudio"\n$ vim estudio/settings.py\n```\n\n- Agregar __```gea```__ y ```nested_admin``` a las ```INSTALLED_APPS```:\n\n```python\nINSTALLED_APPS = (\n    ...\n    \'gea.apps.GeaConfig\',\n    \'nested_admin\',\n)\n```\n\n- Se pueden acomodar el Idioma y la TimeZone\n\n```python\nLANGUAGE_CODE = \'es-AR\'\nTIME_ZONE = \'America/Argentina/Buenos_Aires\'\n```\n\n#### Para utilizar PostgreSQL (opcional)\n\n- Opcionalmente, configurar la Base de Datos para utilizar PostgreSQL, de otro modo, Django usa SQLite3 por defecto. Editar ```settings.py```.\n\n```python\nDATABASES = {\n    \'default\': {\n        \'ENGINE\': \'django.db.backends.postgresql_psycopg2\',\n        \'NAME\': \'gea\',\n        \'USER\': \'<postgresql-user>\',\n        \'PASSWORD\': \'<postgresql-password>\', # be creative\n        \'HOST\': \'localhost\',\n    }\n}\n```\n\ncon esta opción se debe crear la BD, con el comando ```createdb``` de PostgreSQL\n\n```bash\n$ createdb gea\n```\n\n### Editar ```urls.py``` del proyecto Django:\n\n```bash\n$ # dentro de "estudio"\n$ vim estudio/urls.py\n```\n\n- Importar las vistas de ```gea``` y agregar las urls de las aplicaciones que instalamos:\n\n```python\nfrom django.conf.urls import include, path\n\n\nurlpatterns = [\n    ...\n    path(\'gea/\', include(\'gea.urls\')),\n    path(\'_nested_admin/\', include(\'nested_admin.urls\')),\n]\n```\n\n### Base de datos y Superusuario\n\n```bash\n$ # dentro de "estudio"\n$ python manage.py makemigrations gea\n$ python manage.py migrate\n$ python manage.py createsuperuser\n```\n\n```makemigrations``` y ```migrate``` ponen a punto la base de datos, ```createsuperuser``` instala el sistema de autenticación de Django, _Django\'s auth system_, con lo cual, pedirá usuario, mail y contraseña, por ejemplo: _admin_ y _Af7Dr2ujW_. Con estos datos ingresaremos después a la interfaz de administración.\n\n## Archivos estáticos (css, img, js)\n\nPor último, algo muy importante: los archivos de estilo, imágenes y scripts que usará nuestra nueva aplicación.\n\nEditar ```settings.py``` agregando la siguiente linea:\n\n```python\nSTATIC_ROOT = \'./static/\'\n```\n\nY ejecutar:\n```bash\n$ # dentro de "estudio"\n$ python manage.py collectstatic\n```\n\n¡**LISTO**... Ahora podemos probar cómo quedó nuestra django-app!\n\n```bash\n$ # dentro de "estudio"\n$ python manage.py runserver\n```\n\ne ingresamos a [http://127.0.0.1:8000/gea/](http://127.0.0.1:8000/gea/)... con los datos del superusuario que creamos antes.\n\n## LICENCIA\n\n[MIT](LICENSE)\n',
    'author': 'Santiago Pestarini',
    'author_email': 'santiagonob@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/quijot/gea-package',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4',
}


setup(**setup_kwargs)



from django import template

register = template.Library()


@register.simple_tag
def url_replace(request, field, value):
    dict_ = request.GET.copy()
    dict_[field] = value
    return dict_.urlencode()

